django_turnit.migrations package
================================

.. automodule:: django_turnit.migrations
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

django_turnit.migrations.0001_initial module
--------------------------------------------

.. automodule:: django_turnit.migrations.0001_initial
    :members:
    :undoc-members:
    :show-inheritance:

django_turnit.migrations.0002_pdffilepage_file_size module
----------------------------------------------------------

.. automodule:: django_turnit.migrations.0002_pdffilepage_file_size
    :members:
    :undoc-members:
    :show-inheritance:


